PALM-meteo: palmmeteo.plugins.WritePluginMixin Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | List of all members
palmmeteo.plugins.WritePluginMixin Class Reference
Inheritance diagram for palmmeteo.plugins.WritePluginMixin:
[legend]
Collaboration diagram for palmmeteo.plugins.WritePluginMixin:
[legend]

## Public Member Functions
| write_data (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.Plugin
| check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
| __new__ (cls, name, bases, dct)

## Detailed Description

    Base class mixin for writer plugins.
    Registers 'import_data' method as a handler for event 'write'.

    Abstract methods required to be implemented by derived classes:
        write_data

## Member Function Documentation

## ◆ write_data()

palmmeteo.plugins.WritePluginMixin.write_data | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented in palmmeteo_stdplugins.plot.PlotPlugin, palmmeteo_stdplugins.winddamp.WindDampPlugin, and palmmeteo_stdplugins.write.WritePlugin.

The documentation for this class was generated from the following file:

- palmmeteo/plugins.py